@@ -19,4 +19,4 @@ class URL:
         self.port     = url.port
         self.protocol = url.scheme
         self.username = url.username
-        # TODO: implement url search (query) params
\ No newline at end of file
+        self.query    = url.query
\ No newline at end of file
